MechanismSnapshot

Struct MechanismSnapshot 

pub struct MechanismSnapshot {
    pub identity: MechanismIdentity,
    pub device: DeviceKey,
    pub provider_context: ProviderContextIdentity,
    pub authority: AuthorityIdentity,
    pub coherence: MechanismCoherence,
    pub lifecycle: MechanismLifecycle,
    pub live_allocations: usize,
    pub active_operations: usize,
    pub queued_releases: usize,
    pub quarantined_allocations: usize,
    pub quarantined_bytes: u64,
}
Read-only lifecycle information. Taking a snapshot never invokes a provider.

Fields

identity: MechanismIdentitydevice: DeviceKeyprovider_context: ProviderContextIdentityauthority: AuthorityIdentitycoherence: MechanismCoherencelifecycle: MechanismLifecyclelive_allocations: usizeactive_operations: usizequeued_releases: usize

Allocations whose live record was retired into a prepared release that has not settled yet. These are AllocationReleaseState::Queued.

quarantined_allocations: usize

Allocations whose ownership was retained instead of released.

quarantined_bytes: u64

Bytes still owned by quarantined ownership.

Implementations

Source

impl MechanismSnapshot

pub const fn retains_ownership(&self) -> bool

Whether any ownership is still outstanding in any non-terminal or retained state. Removal is unsafe while this is true.