pub struct MechanismSnapshot {
pub identity: MechanismIdentity,
pub device: DeviceKey,
pub provider_context: ProviderContextIdentity,
pub authority: AuthorityIdentity,
pub coherence: MechanismCoherence,
pub lifecycle: MechanismLifecycle,
pub live_allocations: usize,
pub active_operations: usize,
pub queued_releases: usize,
pub quarantined_allocations: usize,
pub quarantined_bytes: u64,
}Expand description
Read-only lifecycle information. Taking a snapshot never invokes a provider.
Fields
identity: MechanismIdentitydevice: DeviceKeyprovider_context: ProviderContextIdentitycoherence: MechanismCoherencelifecycle: MechanismLifecyclelive_allocations: usizeactive_operations: usizequeued_releases: usizeAllocations whose live record was retired into a prepared release that
has not settled yet. These are AllocationReleaseState::Queued.
quarantined_allocations: usizeAllocations whose ownership was retained instead of released.
quarantined_bytes: u64Bytes still owned by quarantined ownership.
Implementations
Sourceimpl MechanismSnapshot
impl MechanismSnapshot
Sourcepub const fn retains_ownership(&self) -> bool
pub const fn retains_ownership(&self) -> bool
Whether any ownership is still outstanding in any non-terminal or retained state. Removal is unsafe while this is true.